import { T as ThemeInput, L as LanguageInput, C as CodeToHtmlOptions } from './types/types.mjs';
export { A as Awaitable, a as BuiltinLanguages, B as BuiltinThemes, E as ElementsOptions, H as HtmlRendererOptions, d as LanguageRegistration, e as LineOption, c as MaybeArray, M as MaybeGetter, b as MaybeModule, P as PlainTextLanguage, R as RequireKeys, S as StringLiteralUnion, g as ThemeRegisteration, f as ThemeRegisterationRaw, j as ThemedToken, i as ThemedTokenExplanation, h as ThemedTokenScopeExplanation } from './types/types.mjs';

interface WebAssemblyInstantiator {
    (importObject: Record<string, Record<string, WebAssembly.ImportValue>> | undefined): Promise<WebAssembly.WebAssemblyInstantiatedSource | WebAssembly.Instance>;
}
interface ICommonOptions {
    print?(str: string): void;
}
interface IInstantiatorOptions extends ICommonOptions {
    instantiator: WebAssemblyInstantiator;
}
interface IDataOptions extends ICommonOptions {
    data: ArrayBufferView | ArrayBuffer | Response;
}
type OnigurumaLoadOptions = IInstantiatorOptions | IDataOptions;
declare function loadWasm(loader: WebAssemblyInstantiator): Promise<void>;
declare function loadWasm(options: OnigurumaLoadOptions): Promise<void>;
declare function loadWasm(data: ArrayBufferView | ArrayBuffer | Response): Promise<void>;

interface HighlighterCoreOptions {
    themes: ThemeInput[];
    langs: LanguageInput[];
    loadWasm?: OnigurumaLoadOptions | (() => Promise<OnigurumaLoadOptions>);
}
type HighlighterCore = Awaited<ReturnType<typeof getHighlighterCore>>;

declare function getHighlighterCore(options: HighlighterCoreOptions): Promise<{
    codeToThemedTokens: (code: string, lang?: string, theme?: string | undefined, options?: {
        includeExplanation: boolean;
    }) => {
        content: string;
    }[][];
    codeToHtml: (code: string, options?: CodeToHtmlOptions) => string;
    loadLanguage: (...langs: LanguageInput[]) => Promise<void>;
    loadTheme: (...themes: ThemeInput[]) => Promise<void>;
    getLoadedThemes: () => string[];
    getLoadedLanguages: () => string[];
}>;

export { CodeToHtmlOptions, HighlighterCore, HighlighterCoreOptions, LanguageInput, ThemeInput, getHighlighterCore, loadWasm };
