import { T as ThemeInput, B as BuiltinThemes, L as LanguageInput, a as BuiltinLanguages, P as PlainTextLanguage, C as CodeToHtmlOptions, R as RequireKeys } from './types/types.mjs';
export { A as Awaitable, E as ElementsOptions, H as HtmlRendererOptions, d as LanguageRegistration, e as LineOption, c as MaybeArray, M as MaybeGetter, b as MaybeModule, S as StringLiteralUnion, g as ThemeRegisteration, f as ThemeRegisterationRaw, j as ThemedToken, i as ThemedTokenExplanation, h as ThemedTokenScopeExplanation, n as bundledLanguages, m as bundledLanguagesAlias, l as bundledLanguagesBase, k as bundledThemes } from './types/types.mjs';
export { HighlighterCore, HighlighterCoreOptions, getHighlighterCore, loadWasm } from './core.mjs';
export { getWasmInlined } from './wasm.mjs';

interface HighlighterOptions {
    themes?: (ThemeInput | BuiltinThemes)[];
    langs?: (LanguageInput | BuiltinLanguages | PlainTextLanguage)[];
}
type Highlighter = Awaited<ReturnType<typeof getHighlighter>>;
declare function getHighlighter(options?: HighlighterOptions): Promise<{
    codeToHtml(code: string, options?: CodeToHtmlOptions<BuiltinLanguages, BuiltinThemes>): string;
    loadLanguage(...langs: (LanguageInput | BuiltinLanguages | PlainTextLanguage)[]): Promise<void>;
    loadTheme(...themes: (ThemeInput | BuiltinThemes)[]): Promise<void>;
    codeToThemedTokens: (code: string, lang?: string, theme?: string | undefined, options?: {
        includeExplanation: boolean;
    }) => {
        content: string;
    }[][];
    getLoadedThemes: () => string[];
    getLoadedLanguages: () => string[];
}>;

/**
 * Shorthand for codeToHtml with auto-loaded theme and language.
 * A singleton highlighter it maintained internally.
 *
 * Differences from `shiki.codeToHtml()`, this function is async.
 */
declare function codeToHtml(code: string, options: RequireKeys<CodeToHtmlOptions<BuiltinLanguages, BuiltinThemes>, 'theme' | 'lang'>): Promise<string>;

export { BuiltinLanguages, BuiltinThemes, CodeToHtmlOptions, Highlighter, HighlighterOptions, LanguageInput, PlainTextLanguage, RequireKeys, ThemeInput, codeToHtml, getHighlighter };
