import { getWasmInlined } from './wasm.mjs';
import { g as getHighlighterCore, i as isPlaintext } from './chunks/core.mjs';
export { l as loadWasm } from './chunks/core.mjs';
import { bundledLanguagesBase, bundledLanguages } from './langs.mjs';
export { bundledLanguagesAlias } from './langs.mjs';
import { bundledThemes } from './themes.mjs';

async function getHighlighter(options = {}) {
  var _a, _b;
  function resolveLang(lang) {
    if (typeof lang === "string") {
      if (isPlaintext(lang))
        return [];
      const bundle = bundledLanguages[lang];
      if (!bundle)
        throw new Error(`[shikiji] Language \`${lang}\` is not built-in.`);
      return bundle;
    }
    return lang;
  }
  function resolveTheme(theme) {
    if (typeof theme === "string") {
      const bundle = bundledThemes[theme];
      if (!bundle)
        throw new Error(`[shikiji] Theme \`${theme}\` is not built-in.`);
      return bundle;
    }
    return theme;
  }
  const _themes = ((_a = options.themes) != null ? _a : ["nord"]).map(resolveTheme);
  const langs = ((_b = options.langs) != null ? _b : Object.keys(bundledLanguagesBase)).map(resolveLang);
  const core = await getHighlighterCore({
    ...options,
    themes: _themes,
    langs,
    loadWasm: getWasmInlined
  });
  return {
    ...core,
    codeToHtml(code, options2 = {}) {
      return core.codeToHtml(code, options2);
    },
    loadLanguage(...langs2) {
      return core.loadLanguage(...langs2.map(resolveLang));
    },
    loadTheme(...themes) {
      return core.loadTheme(...themes.map(resolveTheme));
    }
  };
}

let _shiki;
async function getShikiWithThemeLang(options) {
  if (!_shiki) {
    _shiki = getHighlighter({
      themes: [options.theme],
      langs: [options.lang]
    });
    return _shiki;
  } else {
    const s = await _shiki;
    await Promise.all([
      s.loadTheme(options.theme),
      s.loadLanguage(options.lang)
    ]);
    return s;
  }
}
async function codeToHtml(code, options) {
  const shiki = await getShikiWithThemeLang(options);
  return shiki.codeToHtml(code, options);
}

export { bundledLanguages, bundledLanguagesBase, bundledThemes, codeToHtml, getHighlighter, getHighlighterCore, getWasmInlined };
